@@ -48,11 +48,10 @@ public:
     /**
      * The identifier that will be removed
      */
-    Q_REQUIRED_RESULT QByteArray identifier();
+    [[nodiscard]] QByteArray identifier();
 
 protected:
     void doStart() override;
 };
 
 }
-
